from distutils.core import setup

setup(
	name = 'combino',
	packages = ['combino'],
	version = '0.0.1',
	license = 'GPL',
	description = 'Brute-Froce Worldlist Generator',
	author = 'v3n0m3x',
	author_email = 'v3n0m3x@itmix.org',
	url = 'http://itmix.org/libraries/combino/',
	download_url = '',
	keywords = ['generate', 'wordlist', 'brute-force'],
	classifiers = [
		'Programming Language :: Python',
		'Operating System :: OS Independent',
		'Development Status :: 1 - Planning',
		'Intended Audience :: Developers',
		'Natural Language :: English',
		'Topic :: Software Development :: Libraries :: Python Modules',
		'License :: OSI Approved :: GNU General Public License (GPL)',
		'Environment :: Console'
		],
	long_description = """\
Brute-Force Wordlist Generator
------------------------------------------------------------

Detects Charsets:

-Non yet to be implemented

Maximum Length = [Not yet implemented]

This version requires Python 2; a Python 3 version is not available, but might be offered in the future.
"""
)